Imports CompanyHub.Models
Imports System.ComponentModel
Imports System.Linq
Imports System.Text
Imports System.Threading.Tasks
Imports Windows.Phone.Management.Deployment
Imports CompanyHub.Utilities
Imports System.Collections.Generic

Namespace CompanyHub.ViewModels
Public Class CompanyPackageViewModel
	Implements INotifyPropertyChanged

	Private _packages As IEnumerable(Of CompanyPackage)

	Public Sub New()
		LoadData()
	End Sub

	Private Sub LoadData()
		' Get list of packages and populate properties
		_packages = CompanyPackage.GenerateData

		UpdatePackageStatus()
	End Sub

Public Sub UpdatePackageStatus()
	Dim devicePkgs = InstallationManager.FindPackagesForCurrentPublisher

	For Each pkg In _packages
		Dim qry = devicePkgs.Where(Function(p) p.Id.ProductId = pkg.Id)
		If qry.Count > 0 Then
			Dim devicePkg = qry.First
			Dim devicePkgVersion = PackageVersionHelper.VersionToString(devicePkg.Id.Version)

			pkg.Status = If(PackageVersionHelper.IsNewer(pkg.Version, devicePkgVersion), CompanyPackageStatus.Update, CompanyPackageStatus.Installed)
		Else
			pkg.Status = CompanyPackageStatus.New
		End If
	Next pkg

	_newPackages = _packages.Where(Function(p) p.Status = CompanyPackageStatus.New).ToList
	_updatePackages = _packages.Where(Function(p) p.Status = CompanyPackageStatus.Update).ToList
	_installedPackages = _packages.Where(Function(p) p.Status = CompanyPackageStatus.Installed).ToList

	' Fire notifications for all properties
	NotifyPropertyChanged("NewPackages")
	NotifyPropertyChanged("UpdatePackages")
	NotifyPropertyChanged("InstalledPackages")
End Sub

	Private _newPackages As IEnumerable(Of CompanyPackage)
	Public ReadOnly Property NewPackages As IEnumerable(Of CompanyPackage)
		Get
			Return _newPackages
		End Get
	End Property

	Private _updatePackages As IEnumerable(Of CompanyPackage)
	Public ReadOnly Property UpdatePackages As IEnumerable(Of CompanyPackage)
		Get
			Return _updatePackages
		End Get
	End Property

	Private _installedPackages As IEnumerable(Of CompanyPackage)
	Public ReadOnly Property InstalledPackages As IEnumerable(Of CompanyPackage)
		Get
			Return _installedPackages
		End Get
	End Property

Public Function FindPackage(ByVal id As String) As CompanyPackage
	Return _packages.Where(Function(p) p.Id = id).FirstOrDefault
End Function

	Private _selectedPackage As CompanyPackage
	Public Property SelectedPackage As CompanyPackage
		Set(ByVal value As CompanyPackage)
			_selectedPackage = value
			NotifyPropertyChanged("SelectedPackage")
		End Set
		Get
			Return _selectedPackage
		End Get
	End Property

        Public Event PropertyChanged As PropertyChangedEventHandler Implements INotifyPropertyChanged.PropertyChanged

	Private Sub NotifyPropertyChanged(ByVal propertyName As String)
            Dim handler As PropertyChangedEventHandler = Nothing

		If Nothing IsNot handler Then
			handler(Me, New PropertyChangedEventArgs(propertyName))
		End If
	End Sub
End Class
End Namespace
